==> tapin-1.0.x-dev.tar.gz: tapin/src/Plugin/rest/resource/GetOrderRestResource.php <==
<?php

namespace Drupal\tapin\Plugin\rest\resource;

use Drupal;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\rest\ModifiedResourceResponse;
use Drupal\rest\Plugin\ResourceBase;
use Drupal\tapin\TapinServiceInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a resource to get view modes by entity and bundle.
 *
 * @RestResource(
 *   id = "get_order_rest_resource",
 *   label = @Translation("Get order rest resource"),
 *   uri_paths = {
 *     "canonical" = "/api/tapin/get-order"
 *   }
 * )
 */
class GetOrderRestResource extends ResourceBase implements DependentPluginInterface {

  /**
   * A current user instance.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  protected $orderService;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, array $serializer_formats, LoggerInterface $logger, TapinServiceInterface $orderService) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
    $this->orderService = $orderService;
    $this->currentUser = Drupal::currentUser();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->getParameter('serializer.formats'),
      $container->get('logger.factory')->get('tapin'),
      $container->get('tapin.tapin')
    );
  }

  /**
   * Responds to GET requests.
   *
   *
   * @return \Drupal\rest\ModifiedResourceResponse
   *   The HTTP response object.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\HttpException
   *   Throws exception expected.
   */
  public function get() {
    // add sercice to get order
    $getOrder = $this->orderService->getOrder();
    return new ModifiedResourceResponse($getOrder, 200);
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    return [];
  }

}

==> tapin-1.2.x-dev.tar.gz: tapin/src/Plugin/rest/resource/GetOrderRestResource.php <==
<?php

namespace Drupal\tapin\Plugin\rest\resource;

use Drupal;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\rest\ModifiedResourceResponse;
use Drupal\rest\Plugin\ResourceBase;
use Drupal\tapin\TapinServiceInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a resource to get view modes by entity and bundle.
 *
 * @RestResource(
 *   id = "get_order_rest_resource",
 *   label = @Translation("Get order rest resource"),
 *   uri_paths = {
 *     "create" = "/api/tapin/get-order"
 *   }
 * )
 */
class GetOrderRestResource extends ResourceBase implements DependentPluginInterface {

  /**
   * A current user instance.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  protected $orderService;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, array $serializer_formats, LoggerInterface $logger, TapinServiceInterface $orderService) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
    $this->orderService = $orderService;
    $this->currentUser = Drupal::currentUser();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->getParameter('serializer.formats'),
      $container->get('logger.factory')->get('tapin'),
      $container->get('tapin.tapin')
    );
  }

  /**
   * Responds to GET requests.
   *
   *
   * @return \Drupal\rest\ModifiedResourceResponse
   *   The HTTP response object.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\HttpException
   *   Throws exception expected.
   */
  public function post($data) {
    // add sercice to get order
    $getOrder = $this->orderService->getOrder($data['page'], $data['limit'], $data['order_id']);
    return new ModifiedResourceResponse($getOrder, 200);
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    return [];
  }

}
